pico-8 cartridge // http://www.pico-8.com
version 8
__lua__
function _init()
 init_globals()
 init_mob()
 init_plyrs()
 init_wave()
 init_sfx()
end

function _update60()
 frame+=1
 cam.x = (cam.x+cam.dx) % (cols * 8)
 cam.dx = (cam.dx + cam.ddx) % 32767
 cam.ddx = 0.000125
 if (winner == false) then
  update_players()
 end
end

function _draw()
	draw_background()
 draw_mob()
 if (winner) then
  draw_winner()
 else
  draw_plyr_ui()
 end
 -- draw_debug()
end

--------------------------------
-- init functions
--------------------------------

function init_globals()
 frame = 0
 palt(0, false)
 palt(14, true)
 cam = { 
  x = 0, 
  dx = 0.75,
  ddx = 0
 }
 cols = 32
 rows = 16
 tplyrs = 4
 winner = false
 winning_player = 0
end

function init_mob()
 mob = {
  fields = 5,
  --[[ x0,x1,y0,sprite+offset,
       stored in one list for
       better performance --]]
  xys = {},
 }
 
 mobidx = {
  64,64,64,64, --pad with player idx
  1,6,11,
  17,22,27,
  33,38,43,
  49,54,59
 }

 for j = 1,rows do
  for i = 1,cols do
   local x0, x1, y0,
    sidx, soffset =
    -wave(j*9-9,158,168,72),
    rndgs(8),
    rndgs(3)+1.5,
    tplyrs-flr(-rnd(12)),
    flr(rnd(4))
   add(mob.xys, x0)
   add(mob.xys, x1)
   add(mob.xys, y0)
   add(mob.xys, sidx)
   add(mob.xys, soffset)
  end
 end
end

function init_plyrs()
 -- player height array length
 hlength = 10

 plyrs = {}
 for i=1,tplyrs do
  local xpos = flr(
   rndgs(cols/2) +
   i*cols/4
  )%cols
 	local p = { 
 	 -- x,y pos in columns,rows
   x= xpos,
   y = flr(rows/8 +
    ((i-1)%(tplyrs))*rows/4),
   -- button pressed?
   b = false,
   -- jump height
   h = 0,
   ch = 0, -- jump charge
   -- vertical speed
   dy = 0,
   -- succesfull jumps
   score = 0
  }
  add(plyrs, p)
  
  -- put player in mob
  -- note how we keep using
  -- xys for jitter
  local idx = 
   p.x + p.y * cols
  mob.xys[idx*mob.fields+4] = i
 end
 
end

function init_wave()
 -- pre-calc wave path for
 -- faster rendering
 wavelut = {}
 for x = 0,128 do
  add(wavelut,
  -wave(x, 64, 52, 3) +
   wave(x, 54, 8, 6) +
   wave(x, 48, 16, 5) +
   wave(x, 44, 32, 5) +
   wave(x, 40, 32, 4) +
   wave(x, 36, 32, 4) +
   wave(x, 32, 32, 4) +
   wave(x, 28, 32, 4))
 end
end

function init_sfx()
 playing=0
 music(0)
end

--------------------------------
-- update functions
--------------------------------


--[[ p1/p3: , p2/p4: 
     hold button to charge
     release to jump
     hold too long = lose life
     can't charge/jump in air
     --]]
function update_players()

 for i=1,#plyrs do
  local p = plyrs[i]
  
  -- update buttons
  p.b = btn(
   (i-1)%2,
   ((i-1)/2 + 1)%2
  )
  
		-- prev height
  local ph = p.h

  -- slow speed + gravity
  -- if on ground -> 0
		p.dy = (ph > 0) and 
		 p.dy * 15/16 - 0.125 or 0		
		
		
		-- charge/jump logic
		if (ph <= 0) then
   if (p.b) then
    p.ch = min(p.ch+0.125, 8)
   else
    p.dy += p.ch
    p.ch = 0
   end
  else
   p.ch = 0
  end
  
  -- never fall below ground
  p.h = max(ph + p.dy, 0)
  
  -- update score
 	local must_jmp, succes_jmp = 
 	 jumppoint(p)
  if (must_jmp and succes_jmp ) then
   p.score += 1
  end
  
  -- winner?
  if (p.score > 150) then
   winner = true
   winning_player = i
  end
  
 end
end

--------------------------------
-- draw functions
--------------------------------


function draw_background()
 rectfill(0,0,128,32,12)
 rectfill(0,33,128,128,0)
 rectfill(0,113,128,128,5)
 
 -- clouds and blimp
 spr(201, 128 - ((432+cam.x)/5%176), 11, 2,2)
 spr(203, 128 - ((12+cam.x)/3%176), 8)
 spr(219, 128 - ((683+cam.x)/2%176), 2)
 spr(220, 128 - ((123+cam.x)*3/4%176), 6)
 spr(205, 128 - ((295+cam.x)*2/3%176), 12, 2,2)
 
end

function draw_mob()
 local col, xys,
  sidx, cidx, idx, 
  x, x0, x1, x2, 
  y, y0, y1 = 
  	flr(shr(cam.x,3)), 
  	mob.xys
 
 for j = 1,rows do
  for i = 1,19 do
   x = i*9 - 9 - flr(cam.x%8)
 	 y = j*5

   cidx = 
    ((i+col) % cols)
	  idx = (j-1)*cols+cidx
	  idx = idx*mob.fields
	  x0 = xys[idx+1]
	  x1 = xys[idx+2]
	  y0 = xys[idx+3]

   y1 = x > 0 and 
    x < #wavelut and 
    wavelut[x] or 0

   x2 = wave(x, 52, 32, 4) + j*2

			sidx,x = xys[idx+4], x
			
			----------------------------
			--draw seats and players/mob
			----------------------------

			-- seat
 	 spr(192,x+x0+x2,y+24)

   if (sidx<5) then
    draw_plyr(sidx, x+x0+x2, y)
   else
    draw_mobster(
     sidx,
     xys[idx+4],
     x+x0+x1+x2,
     y -y0 - y1*y0*0.75 + 24
    )
   end
  end
 end

 -- fence + wall
 for i=0,2 do
   spr(240, i*8*16 - (cam.x)%176, 106, 16,1)
   spr(224, i*8*16 - (cam.x)%176, 114, 16,1)
   spr(224, i*8*16 - (cam.x)%176, 122, 16,1)
 end
end


function draw_plyr(i,x,y)
 local p = plyrs[i]	
	local idx = i*32+32 + 
  2 * (flr(shr(cam.x,3))%4)
 spr(idx, x-5, y-p.h+15, 2, 2)

end

function draw_mobster(i,i0,x,y)
 i = mobidx[i] +
 (i0 + flr(shr(cam.x,3)))%4
 spr(i,x,y)
end

function draw_plyr_ui()
 -- holy shit last minute
 -- dirty magic number hack
 -- for sprite indexes, batman!
 local idx = {139, 142, 171, 174}
 for i=1,#plyrs do
  local p = plyrs[i]
  spr(idx[i], i*32-29, 110, 2, 2)
  print(p.score, i*32-28, 116, 7)
  draw_plyr(i, i*32-10, 92)
 end
end

function draw_winner()
 local i = winning_player
 local idx = {138, 141, 170, 173}
  spr(idx[i], 46, 50, 3, 2)
  print("win!!", 48, 56, 7)
  draw_plyr(i, 76, 34)
end

function draw_debug()
  -- debug player info
 for i=1,#plyrs do
  draw_plyr(i, 10, i*24)
 end
end

--------------------------------
-- helper functions
--------------------------------

function hidx()
 return
  frame%hlength + 1,
	 (frame+hlength-1)%hlength + 1 
end

--[[ approx gaussian by taking
     normalised sum of 32 rnd
     calls. for performance
     reasons it is only used
     in lut generation --]]
function rndgs(amp)
 amp = amp or 1
 return amp * (rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd()+rnd()+rnd()+
  rnd()+rnd() - 16) * 0.0625
end


--[[ used in lut generation
     to create different
     shaped paths by summing
     with different widths
     and amplitude --]]
function wave(t,t0,w,amp)
	t = abs( (t0-t) / (w*2) )
 if (t <= 0.5) then
  return 0.5 * amp * (1+cos(t))
 end
 return 0
end

function jumppoint(p)
 local cpos =
  (4-flr(-shr(cam.x,3)))%cols
 local dist = cpos - p.x
	-- jump point? right height?
	return 
	 (dist <= 0 and dist > -5),
	 (p.h > 4 and p.h < 32)
end
__gfx__
99999999eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
99999999ee8888eeee8888eeee8888eeee8888ee00000000ee5555eeee5555eeee5555eeee5555ee00000000ee3333eeee3333eeee3333eeee3333ee00000000
99999999e88888eee88888eee88888eee88888ee00000000e55555eee55555eee55555eee55555ee00000000e33333eee33333eee33333eee33333ee00000000
99999999ee0f0feeeef0f0eeeef0f0eeee0f0fee00000000ee0404eeee4040eeee4040eeee0404ee00000000ee0505eeee5050eeee5050eeee0505ee00000000
99999999eeffffeeeeffffeee8ffff8ee8ffff8e00000000ee4444eeee4444eee544445ee544445e00000000ee5555eeee5555eee355553ee355553e00000000
99999999e888888ee888888ee888888ee888888e00000000e555555ee555555ee555555ee555555e00000000e333333ee333333ee333333ee333333e00000000
99999999e811118ee811118eee1111eeee1111ee00000000e511115ee511115eee1111eeee1111ee00000000e311113ee311113eee1111eeee1111ee00000000
99999999ee1ee1eeee1ee1eeee1ee1eeee1ee1ee00000000ee1ee1eeee1ee1eeee1ee1eeee1ee1ee00000000ee1ee1eeee1ee1eeee1ee1eeee1ee1ee00000000
aaaaaaaaeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
aaaaaaaaee2222eeee2222eeee2222eeee2222ee00000000eeffffeeeeffffeeeeffffeeeeffffee00000000ee1111eeee1111eeee1111eeee1111ee00000000
aaaaaaaae22222eee22222eee22222eee22222ee00000000efffffeeefffffeeefffffeeefffffee00000000e11111eee11111eee11111eee11111ee00000000
aaaaaaaaee0f0feeeef0f0eeeef0f0eeee0f0fee00000000ee0404eeee4040eeee4040eeee0404ee00000000ee0505eeee5050eeee5050eeee0505ee00000000
aaaaaaaaeeffffeeeeffffeee2ffff2ee2ffff2e00000000ee4444eeee4444eeef4444feef4444fe00000000ee5555eeee5555eee155551ee155551e00000000
aaaaaaaae222222ee222222ee222222ee222222e00000000effffffeeffffffeeffffffeeffffffe00000000e111111ee111111ee111111ee111111e00000000
aaaaaaaae211112ee211112eee1111eeee1111ee00000000ef1111feef1111feee1111eeee1111ee00000000e100001ee100001eee0000eeee0000ee00000000
aaaaaaaaee1ee1eeee1ee1eeee1ee1eeee1ee1ee00000000ee1ee1eeee1ee1eeee1ee1eeee1ee1ee00000000ee0ee0eeee0ee0eeee0ee0eeee0ee0ee00000000
11111111eeeeeeeeeeeeeeeeeeeeeeeeee8888ee00000000eeeeeeeeeeeeeeeeeeeeeeeeee5555ee00000000eeeeeeeeeeeeeeeeeeeeeeeeee3333ee00000000
11111111ee8888eeeeeeeeeeee8888eee88888ee00000000ee5555eeeeeeeeeeee5555eee55555ee00000000ee3333eeeeeeeeeeee3333eee33333ee00000000
11111111e88888eeee8888eee88888eeee0f0fee00000000e55555eeee5555eee55555eeee0404ee00000000e33333eeee3333eee33333eeee0505ee00000000
11111111ee0f0feee88888eeee0f0feee8f0ff8e00000000ee0404eee55555eeee0404eee540445e00000000ee0505eee33333eeee0505eee350553e00000000
11111111eeffffeeee0f0feeeef0ffeee888888e00000000ee4444eeee0404eeee4044eee555555e00000000ee5555eeee0505eeee5055eee333333e00000000
11111111e888888eeeffffeee888888eee1111ee00000000e555555eee4444eee555555eee1111ee00000000e333333eee5555eee333333eee1111ee00000000
11111111e811118ee888888eee1111eeee1ee1ee00000000e511115ee555555eee1111eeee1ee1ee00000000e311113ee333333eee1111eeee1ee1ee00000000
11111111ee1ee1eee811118eee1ee1eeeeeeeeee00000000ee1ee1eee511115eee1ee1eeeeeeeeee00000000ee1ee1eee311113eee1ee1eeeeeeeeee00000000
cccccccceeeeeeeeeeeeeeeeeeeeeeeeee2222ee00000000eeeeeeeeeeeeeeeeeeeeeeeeeeffffee00000000eeeeeeeeeeeeeeeeeeeeeeeeee1111ee00000000
ccccccccee2222eeeeeeeeeeee2222eee22222ee00000000eeffffeeeeeeeeeeeeffffeeefffffee00000000ee1111eeeeeeeeeeee1111eee11111ee00000000
cccccccce22222eeee2222eee22222eeee0f0fee00000000efffffeeeeffffeeefffffeeee0404ee00000000e11111eeee1111eee11111eeee0505ee00000000
ccccccccee0f0feee22222eeee0f0feee2f0ff2e00000000ee0404eeefffffeeee0404eeef4044fe00000000ee0505eee11111eeee0505eee150551e00000000
cccccccceeffffeeee0f0feeeef0ffeee222222e00000000ee4444eeee0404eeee4044eeeffffffe00000000ee5555eeee0505eeee5055eee111111e00000000
cccccccce222222eeeffffeee222222eee1111ee00000000effffffeee4444eeeffffffeee1111ee00000000e111111eee5555eee111111eee0000ee00000000
cccccccce211112ee222222eee1111eeee1ee1ee00000000ef1111feeffffffeee1111eeee1ee1ee00000000e100001ee111111eee0000eeee0ee0ee00000000
ccccccccee1ee1eee211112eee1ee1eeeeeeeeee00000000ee1ee1eeef1111feee1ee1eeeeeeeeee00000000ee0ee0eee100001eee0ee0eeeeeeeeee00000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee9eeeeeeee9eee000000000000000000000000000000000000000000000000
eee9eeeeeeee9eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee9ee9999ff9999ee9000000000000000000000000000000000000000000000000
9ee9999ff9999ee9eee9eeeeeeee9eeeeeeeeeeeeeeeeeeeeee9eeeeeeee9eee9ee9999ff9999ee9000000000000000000000000000000000000000000000000
9ee9999ff9999ee99ee9999ff9999ee9eee9eeeeeeee9eee9ee9999ff9999ee99999999999999999000000000000000000000000000000000000000000000000
99999999999999999ee9999ff9999ee99ee9999ff9999ee99ee9999ff9999ee9444ffff99ffff444000000000000000000000000000000000000000000000000
444fff9999fff44499999999999999999ee9999ff9999ee99999999999999999eeef0ff99ff0feee000000000000000000000000000000000000000000000000
eeef0ff99ff0feee444fff9999fff4449999999999999999444fff9999fff444eeef0ffffff0feee000000000000000000000000000000000000000000000000
eeef0ffffff0feeeeeef0ff99ff0feee4449999999999444eeef0ff99ff0feeeeeeffffffffffeee000000000000000000000000000000000000000000000000
eeeffffffffffeeeeeef0ffffff0feeeeeeffff99ffffeeeeeef0ffffff0feeeeeeffff00ffffeee000000000000000000000000000000000000000000000000
eeeffff00ffffeeeeeeffffffffffeeeeeef0ffffff0feeeeeeffffffffffeeeeee999f00f999eee000000000000000000000000000000000000000000000000
eee999f00f999eeeeeeffff00ffffeeeeeeffffffffffeeeeeeffff00ffffeeeeee9f9ffff999eee000000000000000000000000000000000000000000000000
eee9f9ffff999eeeeee999f00f999eeeeeeffff00ffffeeeeee999f00f999eeeeee99999999f9eee000000000000000000000000000000000000000000000000
eee99999999f9eeeeee9f9ffff999eeeeee999f00f999eeeeee9f9ffff999eeeeee99f99f9999eee000000000000000000000000000000000000000000000000
eee99f99f9999eeeeee99999999f9eeeeee9f9ffff999eeeeee99999999f9eeeeee9f99f99f99eee000000000000000000000000000000000000000000000000
eee9f99999f99eeeeee99f99f9999eeeeee99999999f9eeeeee99f99f9999eeeeee9999999999eee000000000000000000000000000000000000000000000000
eee9999f99999eeeeee99999999f9eeeeee99f99f9999eeeeee99999999f9eeeeeeeeeeeeeeeeeee000000000000000000000000000000000000000000000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeaaaaaaaaaaeee000000000000000000000000000000000000000000000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeaaaaaaaaaaeee000000000000000000000000000000000000000000000000
eeeaaaaaaaaaaeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeaa0aaaa0aaeee000000000000000000000000000000000000000000000000
eeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeeeeeeeeeeeeeeeeeaaaaaaaaaaeeeeeeaa0aaaa0aaeee000000000000000000000000000000000000000000000000
eeeaa0aaaa0aaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaa999aaaaeee000000000000000000000000000000000000000000000000
eeeaa0aaaa0aaeeeeeeaa0aaaa0aaeeeeeeaaaaaaaaaaeeeeeeaa0aaaa0aaeeeeeeaa99999aaaeee000000000000000000000000000000000000000000000000
eeeaaa999aaaaeeeeeeaa0aaaa0aaeeeeeeaaaaaaaaaaeeeeeeaa0aaaa0aaeeeeeea999994aaaeee000000000000000000000000000000000000000000000000
eeeaa99999aaaeeeeeeaaa999aaaaeeeeeeaa0aaaa0aaeeeeeeaaa999aaaaeeeeeea44444aaaaeee000000000000000000000000000000000000000000000000
eeea999994aaaeeeeeeaa99999aaaeeeeeeaaa999aaaaeeeeeeaa99999aaaeeeeeeaaaaaaaaaaeee000000000000000000000000000000000000000000000000
eeea44444aaaaeeeeeea999994aaaeeeeeeaa99999aaaeeeeeea999994aaaeeeeeeaaaaaaaaaaeee000000000000000000000000000000000000000000000000
eeeaaaaaaaaaaeeeeeea44444aaaaeeeeeea999994aaaeeeeeea44444aaaaeeeeeeaaaaaaaaaaeee000000000000000000000000000000000000000000000000
eeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeea44444aaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaa9aaaeee000000000000000000000000000000000000000000000000
eeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaa99aaeee000000000000000000000000000000000000000000000000
eeeaaaaaa9aaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaaaaaeeeeeeaaaaaaa99aeee000000000000000000000000000000000000000000000000
eeeaaaaaa99aaeeeeeeaaaaaa9aaaeeeeeeaaaaaaaaaaeeeeeeaaaaaa9aaaeeeeeeeeeeeeeeeeeee000000000000000000000000000000000000000000000000
eeeaaaaaaa99aeeeeeeaaaaaa99aaeeeeeeaaaaaa9aaaeeeeeeaaaaaa99aaeeeeeeeeeeeeeeeeeee000000000000000000000000000000000000000000000000
ee666eeeeee666eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee6666eeee6666eeeeeeeeeeeeeeeeee7eeeeeeeeeeeeeeeeeeeeeee7eeeeeee
e61116eeee61116eee666eeeeee666eeeeeeeeeeeeeeeeeeee666eeeeee666eee61111666611116eeeeeeeeeeeeeeeee97eeeeeeeeeeeeeeeeeeeeeea7eeeeee
e61611666611616ee61116eeee61116eee666eeeeee666eee61116eeee61116ee61661111116616eeeeeeeeeeeeeeeee997eeeeeeeeeeeeeeeeeeeeeaa7eeeee
e61661111116616ee61611666611616ee61116eeee61116ee61611666611616ee61111111111116e99999999999979779999eeeeaaaaaaaaaaaa7a77aaaaeeee
e61111111111116ee61661111116616ee61611666611616ee61661111116616ee61111111111116e999999999999999999999eeeaaaaaaaaaaaaaaaaaaaaaeee
e61111111111116ee61111111111116ee61661111116616ee61111111111116ee61101111110116e9999999999999999999997eeaaaaaaaaaaaaaaaaaaaaa7ee
e61101111110116ee61111111111116ee61111111111116ee61111111111116ee61101111110116e99999999999999999999997eaaaaaaaaaaaaaaaaaaaaaa7e
e61101111110116ee61111111111116ee61111111111116ee61101111110116ee61111100111116e999999999999999999999999aaaaaaaaaaaaaaaaaaaaaaaa
e61111100111116ee61101111110116ee61111111111116ee61101111110116ee61111600611116e999999999999999999999994aaaaaaaaaaaaaaaaaaaaaaa9
e61111600611116ee61111100111116ee61101111110116ee61111100111116ee61116666661116e99999999999999999999994eaaaaaaaaaaaaaaaaaaaaaa9e
e61116666661116ee61111600611116ee61111100111116ee61111600611116ee61166111166116e9999999999999999999994eeaaaaaaaaaaaaaaaaaaaaa9ee
e61166111166116ee61116666661116ee61111600611116ee61116666661116ee61111111111116e999999999999999999994eeeaaaaaaaaaaaaaaaaaaaa9eee
e61111111111116ee61166111166116ee61116666661116ee61166111166116ee61111166111116e44444444444444449994eeee9999999999999999aaa9eeee
e61111166111116ee61111111111116ee61166111166116ee61111111111116ee61111111111116eeeeeeeeeeeeeeeee994eeeeeeeeeeeeeeeeeeeeeaa9eeeee
e61111111111116ee61111111111116ee61111111111116ee61111166111116ee61111111111116eeeeeeeeeeeeeeeee94eeeeeeeeeeeeeeeeeeeeeea9eeeeee
e66666666666666ee66666666666666ee66666666666666ee66666666666666ee66666666666666eeeeeeeeeeeeeeeee4eeeeeeeeeeeeeeeeeeeeeee9eeeeeee
ee666eeeeee666eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee666eeeeee666eeeeeeeeeeeeeeeeee7eeeeeeeeeeeeeeeeeeeeeee7eeeeeee
ee6c66666666c6eeee666eeeeee666eeeeeeeeeeeeeeeeeeee666eeeeee666eeee6c66666666c6eeeeeeeeeeeeeeeeee17eeeeeeeeeeeeeeeeeeeeeec7eeeeee
ee6cccccccccc6eeee6c66666666c6eeee666eeeeee666eeee6c66666666c6eeee6cccccccccc6eeeeeeeeeeeeeeeeee117eeeeeeeeeeeeeeeeeeeeecc7eeeee
ee6cccccccccc6eeee6cccccccccc6eeee6c66666666c6eeee6cccccccccc6eeee6cccccccccc6ee11111111111171771111eeeecccccccccccc7c77cccceeee
ee6cccccccccc6eeee6cccccccccc6eeee6cccccccccc6eeee6cccccccccc6eeee6cccccccccc6ee111111111111111111111eeeccccccccccccccccccccceee
ee6777cccc7776eeee6cccccccccc6eeee6cccccccccc6eeee6cccccccccc6eeee6777cccc7776ee1111111111111111111117eeccccccccccccccccccccc7ee
ee67077cc77076eeee6777cccc7776eeee6cccccccccc6eeee6777cccc7776eeee67077cc77076ee11111111111111111111117ecccccccccccccccccccccc7e
ee670777777076eeee67077cc77076eeee6777cccc7776eeee67077cc77076eeee670777777076ee111111111111111111111111cccccccccccccccccccccccc
ee677777777776eeee670777777076eeee67077cc77076eeee670777777076eeee677777777776ee111111111111111111111110ccccccccccccccccccccccc1
ee677777777776eeee677777777776eeee670777777076eeee677777777776eeee677777777776ee11111111111111111111110ecccccccccccccccccccccc1e
ee6ccc7007ccc6eeee677777777776eeee677777777776eeee677777777776eeee6ccc7007ccc6ee1111111111111111111110eeccccccccccccccccccccc1ee
ee6ccc7007ccc6eeee6ccc7007ccc6eeee677777777776eeee6ccc7007ccc6eeee6ccc7007ccc6ee111111111111111111110eeecccccccccccccccccccc1eee
ee6ccc7777ccc6eeee6ccc7007ccc6eeee6ccc7007ccc6eeee6ccc7007ccc6eeee6ccc7777ccc6ee00000000000000001110eeee1111111111111111ccc1eeee
ee6cccccccccc6eeee6ccc7777ccc6eeee6ccc7007ccc6eeee6ccc7777ccc6eeee6cccccccccc6eeeeeeeeeeeeeeeeee110eeeeeeeeeeeeeeeeeeeeecc1eeeee
ee6cccccccccc6eeee6cccccccccc6eeee6ccc7777ccc6eeee6cccccccccc6eeee6cccccccccc6eeeeeeeeeeeeeeeeee10eeeeeeeeeeeeeeeeeeeeeec1eeeeee
ee666666666666eeee666666666666eeee666666666666eeee666666666666eeee666666666666eeeeeeeeeeeeeeeeee0eeeeeeeeeeeeeeeeeeeeeee1eeeeeee
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee77777777eeee00000000
ee77776eee77776eee77776eee77776eee77776e00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeee76eeeeeeeeeeeeee666666666666ee00000000
ee76666eee76666eee76666eee76666eee76666e00000000cccccccccccccccc00000000eeeeeeeee77eeeeee7777eeeeeeeeeeee66666666666666e00000000
ee76666eee76666eee76666eee76666eee76666e00000000cccccccccccccccc00000000eeeeeeee776eeeee7777777eeeeeeeeee77777777777777700000000
ee66666eee66666eee66666eee66666eee66666e00000000cccccccccccccccc00000000eeeee7777776eeeee6666677eeeeeeeee66666666666666600000000
666555666665556666655566666555666665556600000000cccccccccccccccc00000000ee7777777777777eeeeeeeeeeeeeeeeeee666666666666ee00000000
555555555555555555555555555555555555555500000000cccccccccccccccc00000000e77777777777666eeeeeeeeeeeeeeeeeeeee50505055eeee00000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000cccccccccccccccc00000000eeeee66776666eeeeeeeeeeeeeeeeeeeeeee55555555eeee00000000
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000cccccccccccccccc00000000eeeeeee666eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
ee77776eee77776eee77776eee77776eee77776e00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeeee77eeeeeeeeeeeeeeeeeeeeeeeeeee00000000
ee76666eee76666eee76666eee76666eee76666e00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeee7777eeeeeeeeeeeeeeeeeeeeeeeeee00000000
ee76666eee76666eee76666eee76666eee76666e00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeee77666eee777eeeeeeeeeeeeeeeeeeee00000000
ee66666eee66666eee66666eee66666eee66666e00000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeee66eeeeee67777eeeeeeeeeeeeeeeee00000000
666555666665556666655566666555666665556600000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
555555555555555555555555555555555555555500000000cccccccccccccccc00000000eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee00000000
65666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555
66566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555
65666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555
66566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee
77777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777
66e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e6
6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee
6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee6eee
66e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e666e6
66666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555
__label__
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccc3333ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccc33333ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccc0505ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccc5555cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc7
cccccccccccccccccccccccccccccccccccccccc333333cccccccccccccccc8888cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccccccccccccccccccccccc311113ccccccccccccccc88888cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccc1cc1ccccccccccccccccc0f0fcccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccc777cccccccccccccccccccccccccccccccccccccccccffffccccccccccccccccccccccccccccccccccccccccccccccccccc76ccccccccc
ccccccccccccccccccc67777cccccccccccccccc5555ccccccccffffccccc888888ccccccccccccccccccccccccccccccccccccccccccccccccc7777cccccccc
ccccccccccccccccccccccccccccccccccccccc55555cccccccfffffccccc811118cccccccccccccccccccccccccccccccccccccccccccccccc7777777cccccc
cccccccccccccccccccccccccccccccccccccccc0404cccccccc0404cccccc1cc1cccccccccccccccccccccccccccc77777777cccccccccccccc6666677ccccc
ccccccccccccccccccccccccccccccccccccccc54044577ccccf4444cccccccccccccccccccccccccccccccccccc666666666666cccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccc55555576ccccffffffcccccccccccccccccccccccccccccccccc66666666666666ccccccccccccccccccccccc
cccccccccccccccccccccccccccccc2222cccccc11117776cccf1111fcccccccccccccccccccccccccccccccccc777777777777777cccccccccccccccccccccc
ccccccccccccccccccccccccccccc22222cccc7717717777777f1ff1fccccc8888ccccccccccccccccccccccccc666666666666666cccccccccccccccccccccc
ccccccccccccccccccccccccccccc80f0fccc77777777777666c1111ccccc88888cccccccccccccccccccccccccc666666666666cccccccccccccccccccccccc
ccccccccccccccccccccccccccccc2ffff2cccccc11116666ccc1111cccccc0f0fcccccccccccccccccccccccccccc50505055cccccccccccccccccccccccccc
cccccccccccccccccccc1111ccccc222222ccccc111116ccccc11118888cffffffcccccccccccccccccccccccccccc55555555cccccccccccccccccccccccccc
ccccccccccccccccccc11111ccccc811118ccccc85050ccccccc05888881111f888ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccc0505cccccc1111ccc33335555cccccc15050f0f1111411cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccc150551ccccc1111cc3333311111ccccc1111f0ff50504c1cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccc11115555cc11111ccc505000001cccccc00888888555ffccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccccccccccc0055555ccc0505cc355553880cccc3333cc111111111cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccccccccccc8888cccc0cc4040c3333551c33333311cccc33333cc1cc100001cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
cccc8888ccc88888ccccccc444433333111cc1111cc1ccccc5050cccccc0cc0cccccffffcccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccc88888cccc0f0fcccccc555555050500ccc1cc1ccccccc355553cccccccccccccfffffccccccccccccccccccccccccccccccccccccccccccccccccc8888ccc
cccc0f0fccccf0ffcccccc5111155555c01111cccccccccc333333cccccccccccccc0404ccccccccccccccccccccccccccccc3333ccccc2222cccccc88888ccc
ccccf0ffccc888888cccccc1cc133333311111ccccccccccc1111ccccccccccccccc4444cccccccccccccccccccc1111cccc33333cccc22222ccccccc0f0fccc
ccc888888ccc12222cccc77776c31111375050ccc77776ccc1c71776ccccc77776cffffff6cc77776ccc77776cc1111176ccc505076ccc0f0f76cccc7f0ffccc
ccc71111cccc222229cc1111669c1c71665555ccc766633335556666ccccc76666cf1111f6cc72222ccc22226ccc505066cc3555536cc2ffff26cccc555588cc
0003333100007090f9911111999009766111111007663333355566660000076666001ffff6002222200222226000555566003111136002222226000555551000
0033333600002f9ff999050599ffff66610000100666650500406666000006666600fffff60060f0f0000f0f6001111116001111166000133336000004041000
0665050660655599999150551fffff65550600066655355553445556600666555666604046666ffff666ffff660100ffff606050556606333336606540445606
05355553505555444ff111111f0404577776000557773333335557776005577776555444465575555252555565050fffff501505516505505056505555555505
05555333000404061f0f0000f0404407666600000766611111115666600007666600ffffff005555520555556000070404001111116000055556000011116000
55555116000444466f0f0ff0fffffff766660000076661001001768888000766660222211f007404000040406000074044000000066000333333000555516000
00404616005555556fffffffff1111066666003333666600000068888800066666222226160064444000444460000ffffff00066066000322223005555566000
54044556605111156888800fff10016655566333335556600033330f0f0666555660f0f556665555556533335606222211606662222606222226606404056606
555555765011111788888308888005772222505050777650033333ffff055777762ffff27652222765533333650222227650552222250550f0f6505444476505
011116660111116660f0f3888880007222220355553ffff3333505888880076666288882662222266000505060000f0f66000070f0f005555ff6005555556000
01111666005050666f0ff590f0f000760f0f0333333fff333335551111800766668888866600f0f6600355553002ffff2600007ffff055555222005111156003
1111166600555566888888ff0ff00062ffff20111160404505033336010006666600f0f6660ffff6600333333002211116000022222200404112001111166033
0505055668888115611113888888666222222216615444355553113660066655566f0ff556555522655551116606111116602222111254044556606505056605
055556558888801511121221111057711112220777ffff3333337165500777765588888855555562555557615507705055522222655555555555507555555535
1111110000f333311122222100222211111f0f0766f1111111166660000766663333111600040460004046600007150551000f0f600011111600001111110033
555001000f3335555500f0f602222265050fff07666222210016666000076663333366160540445054044560000711111101111f600111111600222200010fff
555606008880555550588883330f0f6555522226662222200066666000066666505066660555555055555560000660000011111220000505660222226600ffff
04055660611554040188888333ffff11111111265550f0f0666555660666555355553556661111666111156606222256006050512601505516600f0f55660040
44465888813334444020f0f05022221000010777762ffff277776555077776533333365572222155333365550222225550150551550111111552ffff25550404
5555888886315555556ffff55531112000000788882222227666600007666633333166002222200333336000070f0f000011111100070000000222222000ffff
111500f0f66151111588888833366660000008888801111076666000076666005051660070f0f0005050600002ffff200aaaaaaaaaa706608888111160111111
66160ffff666610016811118116666600000060f0f0100106666600006666605555666002ffff20355553000022222111aaaaaaaaaa266688888166161111166
55555588885566066651561061655566000666ffff6000666555660666555633333356662222226333333605555111111aa0aaaa0aa255560f0f655566505055
6555551118555577776555507777655500777888888007777655557777655531111357222211ffff76115555555551505aa0aaaa0aaf6555f0ff765555555565
604040661600007666600000766660000076681111800766660000766660111166100222220fffff66010074040000555aaa999aaaaf60088888860001111110
11114466111100222260000076111100007666100100076666000076666111116660070f0f00040466000074444001111aa99999aaa220011111661111000010
1111555155553333226000006111110000666660000006666600006666605050666002ffff20444466000055553333000a999994aaa120111111611111066060
50501155555333330f660066650505006665556600066655566066655566555555888822222ffffff6333351133333065a44444aaaa566050505565050655566
5555716540405050ff5577776150551111165555077776555557777655511111188888611ffff761f3333376550505776aaaaaaaaaa555755555555555765555
1111166144435555322076666111111111160000076666000007666633330000100f0f60fffff661005050660055556665555aaaaaa000111111011111160000
000012255553333331207666600000050506000007666600000766633333066000ffff6000404660035555360333333655555aaaaaaffff00001888800162222
00f01111111111110000661111000005555888800666660000066666050566660888888004044660111133360311113660404aa9aafffff06608888860622222
fff111111661155160666111110006111111888666555660066655565555555668111186ffffff611111115622226155540445a99aa0404555660f0f55560f0f
222205057776555577776550500777100001f0f77655555777765553333335772222517888811557050551522222655555555555557404455557f0ff5552ffff
11115055166600007666605555076555500f0ff66600000766660003111130722222008888801001505510000f0f600001111601111fff111108888880022222
66111111166600007111111111175555508888886600000766633337166100760f0f0070f0f0000111111000ffff11110166161111111111110711110ffff111
6660000066660000111111000016640400011116660000066633333666660066ffff006ffff111160000088882211111066666005051660505061661fffff662
55660660888860666222260000665444400166155660066655505056555666622222668888111116055088888111505066555615055151505516555660404555
55577778888877772222210777765555557776555557777655555556555557621133336111105056555570f0f555555576555511111151111116555574444552
000766660f0f766610f0f10766665111156666000007666ffff3333355555660033333610015055100007ffff0011111160000700000000000660000ffffff02
00076666ffff76666ffff0076666010017666600000766fffff111130404066000050560001111110000888888888000160ffff0660555576066088881118888
3336111188888ffff222220666660000066666000006666040416616044446600055556000000006888881118888866066fffff6665555566666888881688888
333111111111fffff1111222255688886655566006665554444655565555556663333388886055088888615510f0f6555660404555640406555660f0f5550f0f
5056888817716040450722222558888876555557777655ffffff5ffff761155555611888887655550f0f65555ffff655557444455554444655557ffff555ffff
55588888766664444ff760f0f0000f0f66000007666600f1111ffffff66015555560010f0f660000f0ff60008888880000ffffff005555550000888888088888
33310f0f1666fffffff72ffff200ffff66000007666655556616004046600040406000ffff66000888888ffff111183333f1111ffff111153333811118081111
111fffff1666f1111f462222220888888600000666655555666604444660004444555588888688881111fffff1661333336166fffff166133333616610222261
55fffff885556104144651111008111186600666555640405556ffffff6888855555551111888888155160404655560505655560404655565050655562222255
55504041855555ffffff5155177716515557777655574444557888811f8888811104047651550f0f6555544446555555556555540446555355553555570f0f55
00044441600000f1111f0000076666000007666888855555508888801070f0f0054044560000ffff6000ffffff000333333000ffffff00033333300007ffff05
00ffffff60000001661600005555660000076688888511115070f0f0007ffff005555556000888888000f1111f2222111130222211160ffff111600002222255
00f1111f60000006666600055555660000066660f0f61661006f0ff00088888800111163333811118222216612222216616222226616fffff661600002111120
606165156600066655566006040456600666555ffff6555666888888668111ffff1651333336155122222655560f0f6555660f0f555660404555222266555654
5777765555077776555550754044555777765588888855888876118888615fffff7655505057655550f0f65555ffff655552ffff255574044552222276555555
076666000007666600000075555550076668888111180888886608888860000404660005555660000ffff60005555220000222222000ffffff000f0f66000071
07666600000766660000007611110007668888816616000f0f66000f0f6000404466003333336011112222005555512003333111ffff71111008888f66000071
066666000006666600000066166100066660f0f6666600ffff6600f0ff600ffffff600555513611111111200004046603333366fffff61661088888226022226
66555660066655566000666555660666555f0ff6555668888886ffff888ffff11156655555156650505556605404456605050556040465556600f0f126222225
776555507777655550077776555577776588888865578888118fffff11fffff7615557404055555555655557555555553555535540447655557f0ff55550f0f6
6660000076666000000766660000766660011116600888880107040401004046600007444400011111100007611110003333330ffffff60000888888000ffff6
666000007666600000076666000076668888761660070f0f000744440004044660000555555111100010ffff616610007111100888816608888111100ffff222
66600000666660000006666600006668888866666006f0ff000ffffff0ffffff6222251111111116606fffff66660022226610888881668888816610fffff112
556600666555660006665556606665550f0f65556668888833331111f03333152222261551650505556604045556622222556600f0f55660f0f5556600404556
55550077776555007777655550777765f0ff776588887613333376515333336550f0f77655555557655540447655500f0f65550f0ff6555f0ff7655504044655
00000076666000007666600000766668888886688888660105056600000505602ffff26600555511600ffffff60000ffff6000111188001111886000ffffff00
00000076666000007666600000766660888866600f0f660055556600005555605555226605555501600333316600111122200111111601111116600001111600
0000006666600000666660000066666888886660ffff66033333360005555335555516660004040660333331660111111120000505160005051660222266160f
600066655566006665556600666555660f0f55688888866311113660555551360404155665404455660050555660505055660150551661505515622222555660
50007777655500777765550077776555ffff65533336858888765550704041554044565555555555550555565550555565550111111551111115550f0f765550
0000766660000076666000007666600111188033333608888866000054044505555556000011116000333333000111111000555500000000006000ffff660005
00007666600000766660000076666011111180050506000f0f66000055555500111166000016616000333313000ffff010055555600000066060011112260055
0000666660000066666000006666600050516035555300f0ff6600006111100088886600001111600333331600fffff060000404660000666660111111260000
0066655566006665556600666555661505516633333368333386606ffff516088888566061111166065050566060404566054044566062222566005055566054
005777765500577776550057777655111111111177655333336550fffff655050f0f655057505055035555355054044655055555555022222655150551655055
77777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777777
6066666660666766666660666666606666666066666663666566606664666066686660666166616660666666606666666066666660666f666666666666666666
000666660006066666069006666609066666555666660336333600f6fff600061116600601060016006111660006111600066666600622262206c66666666c66
066655566007665659669999ff99996695561116156766161166aaaaaaaaaa661556660666075066666161166661161660666556660721161266cccccccccc66
656665666069756669669999ff99996695666066656a75666166aaaaaaaaaa666566656665617566656166111111661660666566656c75666566cccccccccc66
6666666666699766699999999999999996666666666aa7666666aa0aaaa0aa666666666666611766666111111111111666666666666cc7666666cccccccccc66
55599997977999955444fff9999fff44455aaaa7a77aaaa55555aa0aaaa0aa5555511117177111155561111111111116555cccc7c77cccc55556777cccc77765
56699999999999995666f0ff99ff0f66566aaaaaaaaaaaaa5666aaa999aaaa6656611111111111115661101111110116566ccccccccccccc56667077cc770766
55599999999999997555f0ffffff0f55555aaaaaaaaaaaaa7555aa99999aaa5555511111111111117561101111110116555ccccccccccccc7556707777770765
65697979999999999766ffffffffff66656a777a77aaaaaaa766a999994aaa6665617771111111111761111100111116656c777c777cccccc766777777777766
55597979999999999995ffff00ffff55555aaa7aa7aaaaaaaaa5a44444aaaa5555511171111111111161111600611116555ccc7c7c7cccccccc6777777777765
56697779999999999946999f00f99966566aa77aa7aaaaaaaa96aaaaaaaaaa6656611771111111111161116666661116566cc77c777ccccccc16ccc7007ccc66
555999799999999994559f9ffff99955555aaa7aa7aaaaaaa955aaaaaaaaaa5555511171111111111061166111166116555ccc7c7c7cccccc156ccc7007ccc65
6569997999999999456699999999f966656a777a777aaaaa9566aaaaaaaaaa6665617771111111110561111111111116656c777c777ccccc1566ccc7777ccc66
5559999999999994555599f99f999955555aaaaaaaaaaaa95555aaaaaa9aaa5555511111111111105561111166111116555cccccccccccc15556cccccccccc65
5664444444499946566699999999f96656699999999aaa965666aaaaaa99aa665660000000011106566666666666666656611111111ccc165666666666666666
5555555555599455555555555555555555555555555aa95555555555555555555555555555511055555555555555555555555555555cc1555555555555555555
6566656665694566656665666566656665666566656a956665666566656665666566656665610566656665666566656665666566656c15666566656665666566
55555555555455555555555555555555555555555559555555555555555555555555555555505555555555555555555555555555555155555555555555555555
56665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666566656665666
55555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555555

__gff__
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
__map__
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
__sfx__
0101000001403014002300034300230001040011400124002f3031240018300220001340021000154001f000164031d000174001c0001a4001c400123001e40020403190002340025400274002a4002f40036400
010800001c3501c2501c3501c250263501c250263501c251213502d2502d3502d25021350212502d3502825134350342502d3502d25021350392502d350342511c3011c3010c003000000c003000000c00300000
010800000c053000000c0530c05310053000000c053390060c053000000c0530c05310053000000c053390060c053000000c0530c05310053000000c053390060c053000000c0530c05310053000000c05339006
0108000000000000000c003000000c003000000c0030000000000000000c003000000c003000000c0030000000000000000c003000000c003000000c0030000000000000000c003000000c003000000c00300000
011000001d3501c350213501f3510f3001f2502325023351213502335124350000001d3501f2510e0010e0010000011000130000000000000130000e000000000000000000000000000000000000000000000000
01100000000000000000000000000000000000000000000000000000000e4030e4030e403000000e4530000000000000000000000000000000000000000000000000000000000000000000000000000000000000
01080000103501025010350102501a350102501a350102510000000000000000000000000000000000000000153502125021350212501535015250213501c2510000000000000000000000000000000000000000
001000001c1501c0501c1501c0501c1501c0501c1501c0501f1501f0501f1501f0501f1501f0501f1501f05024100000002410700000241070000000000000000000000000000000000000000000000000000000
001000000e453000000e4530e4530e453000000e453000000e453000000e4530e4530e453000000e453000000e403000000e4030e4030e403000000e403000000000000000000000000000000000000000000000
0010000021150210502115021050211502105021150210501a1501a0501a1501a0501a1501a0501a1501a05000000000000000000000000000000000000000000000000000000000000000000000000000000000
0010000000000000000000000000000000000000000000000000000000000000000000000000000e4530e453000000e4030000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000e4530e4530e4530e45300000000000000000000000000000000000000000000000000000000000000000000000000000000
000200000706014050190401d03023030280302d0403b0503d040010000100004000090000b0000f000140001b000020000100000000000000100000000020000000000000050000900012000190002000028000
000200000d0000c000090000700007000050000500006000030000400000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
__music__
01 02434144
00 02430644
00 02430405
00 02430644
00 02430405
00 0243040a
00 0243040b
00 02430144
00 0207040b
00 02074408
00 02070908
00 02430144
00 0207040a
00 02074448
00 02070948
00 02430144
00 02430144
00 02430104
00 02430104
02 02480101
00 4c424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344
00 41424344

